@@ -251,6 +251,7 @@ class Screen(BaseScreen, RealTerminal):
             + escape.SI
             + move_cursor
             + escape.SHOW_CURSOR)
+        self.flush()
 
         if self._old_signal_keys:
             self.tty_signal_keys(*(self._old_signal_keys + (fd,)))
@@ -746,7 +747,7 @@ class Screen(BaseScreen, RealTerminal):
         cy = 0
         for row in r.content():
             y += 1
-            if osb and osb[y] == row:
+            if osb and y < len(osb) and osb[y] == row:
                 # this row of the screen buffer matches what is
                 # currently displayed, so we can skip this line
                 sb.append( osb[y] )
@@ -935,7 +936,7 @@ class Screen(BaseScreen, RealTerminal):
                     bg = "5;%d" % (a.background_number - 8 + 40)
                 else:
                     # this doesn't work on most terminals
-                    bg = "%d" % (a.background_number + 100)
+                    bg = "%d" % (a.background_number - 8 + 100)
             else:
                 bg = "%d" % (a.background_number + 40)
         else:
